RadioCapabilities

Struct RadioCapabilities 

pub struct RadioCapabilities(/* private fields */);
Radio capabilities

Implementations

Source

impl RadioCapabilities

pub const NONE: Self

Radio supports no capability

pub const ACK_TIMEOUT: Self

Radio supports AckTime event

pub const ENERGY_SCAN: Self

Radio supports Energy Scans

pub const TRANSMIT_RETRIES: Self

Radio supports TX retry logic with collision avoidance (CSMA)

pub const CSMA_BACKOFF: Self

Radio supports CSMA backoff for frame transmission (but no retry)

pub const SLEEP_TO_TX: Self

Radio supports TX security

pub const TRANSMIT_SEC: Self

Radio supports TX security

pub const TRANSMIT_TIMING: Self

Radio supports TX at specific time

pub const RECEIVE_TIMING: Self

Radio supports RX at specific time

Source

impl RadioCapabilities

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u8

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u8) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u8) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u8) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl RadioCapabilities

pub const fn iter(&self) -> Iter<RadioCapabilities>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<RadioCapabilities>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl RadioCapabilities

pub fn none(&self) -> bool

Check if radio supports no capability

pub fn ack_timeout(&self) -> bool

Check if radio supports AckTime event

pub fn energy_scan(&self) -> bool

Check if radio supports Energy Scans

pub fn transmit_retries(&self) -> bool

Check if radio supports transmit retries

pub fn csma_backoff(&self) -> bool

Check if radio supports CSMA backoff

pub fn sleep_to_tx(&self) -> bool

Check if radio supports sleep to TX

pub fn transmit_security(&self) -> bool

Check if radio supports transmit security

pub fn transmit_timing(&self) -> bool

Check if radio supports transmit timing

pub fn receive_timing(&self) -> bool

Check if radio supports receive timing