pub struct RadioCapabilities(/* private fields */);Expand description
Radio capabilities
Implementations
Sourceimpl RadioCapabilities
impl RadioCapabilities
Sourcepub const ACK_TIMEOUT: Self
pub const ACK_TIMEOUT: Self
Radio supports AckTime event
Sourcepub const ENERGY_SCAN: Self
pub const ENERGY_SCAN: Self
Radio supports Energy Scans
Sourcepub const TRANSMIT_RETRIES: Self
pub const TRANSMIT_RETRIES: Self
Radio supports TX retry logic with collision avoidance (CSMA)
Sourcepub const CSMA_BACKOFF: Self
pub const CSMA_BACKOFF: Self
Radio supports CSMA backoff for frame transmission (but no retry)
Sourcepub const SLEEP_TO_TX: Self
pub const SLEEP_TO_TX: Self
Radio supports TX security
Sourcepub const TRANSMIT_SEC: Self
pub const TRANSMIT_SEC: Self
Radio supports TX security
Sourcepub const TRANSMIT_TIMING: Self
pub const TRANSMIT_TIMING: Self
Radio supports TX at specific time
Sourcepub const RECEIVE_TIMING: Self
pub const RECEIVE_TIMING: Self
Radio supports RX at specific time
Sourceimpl RadioCapabilities
impl RadioCapabilities
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Self
pub const fn from_bits_retain(bits: u8) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl RadioCapabilities
impl RadioCapabilities
Sourcepub const fn iter(&self) -> Iter<RadioCapabilities>
pub const fn iter(&self) -> Iter<RadioCapabilities>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<RadioCapabilities>
pub const fn iter_names(&self) -> IterNames<RadioCapabilities>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl RadioCapabilities
impl RadioCapabilities
Sourcepub fn ack_timeout(&self) -> bool
pub fn ack_timeout(&self) -> bool
Check if radio supports AckTime event
Sourcepub fn energy_scan(&self) -> bool
pub fn energy_scan(&self) -> bool
Check if radio supports Energy Scans
Sourcepub fn transmit_retries(&self) -> bool
pub fn transmit_retries(&self) -> bool
Check if radio supports transmit retries
Sourcepub fn csma_backoff(&self) -> bool
pub fn csma_backoff(&self) -> bool
Check if radio supports CSMA backoff
Sourcepub fn sleep_to_tx(&self) -> bool
pub fn sleep_to_tx(&self) -> bool
Check if radio supports sleep to TX
Sourcepub fn transmit_security(&self) -> bool
pub fn transmit_security(&self) -> bool
Check if radio supports transmit security
Sourcepub fn transmit_timing(&self) -> bool
pub fn transmit_timing(&self) -> bool
Check if radio supports transmit timing
Sourcepub fn receive_timing(&self) -> bool
pub fn receive_timing(&self) -> bool
Check if radio supports receive timing